from setuptools import setup

setup(
    name='myBasics',
    version='1.0.0',
    author='Tiancheng Jiao',
    author_email='jtc1246@outlook.com',
    url='https://github.com/jtc1246/myBasics',
    description='Some basic python tools.',
    packages=['myBasics'],
    install_requires=[],
    python_requires='>=3',
    platforms=["all"],
    license='GPL-2.0 License'
)

