from .main import base64ToBin,base64ToStr,strToBase64,binToBase64,getTime,toJson,toUnix

__all__=[
    'base64ToBin','base64ToStr','strToBase64','binToBase64','getTime','toJson','toUnix'
]


__version__='1.0.0'
__license__='GPL-2.0 License'
__author__='Tiancheng Jiao'
__url__='https://github.com/jtc1246/myBasics'
__author_email__='jtc1246@outlook.com'
__description__='Some basic python tools.'


